// rune_c
// from a_new_day_in_the_workshop
// by John Oestmann, Oct 2024
// Code and music released under MIT License and Public Domain/CC0 respectively

(

{
	var tape;

	// c - Bass Harmony, tape = Corrupt Tape Freq Mod
	tape = Lag.ar(Demand.ar(trig: Impulse.ar(5), reset: -1,
		demandUGens: Dseq([1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,
			               1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,
			               1,1,1,1,1,1,1,1,1,1,1,1,1,1,1.05,1.12,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,
			               1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,
			               1,1,1,1,1,1,1,1,0.2,0.9,0.5,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,
			               1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,
			               1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,
			               1,1,1,1,0.89,1,1,1,0.85,0.86,1,1,1,1,1,1,1,1,1,1,0.98,0.84,1,1,1,1,1,
		],repeats: inf)),lagTime: 0.015);

	c = SinOsc.ar(freq: ([60, 64, 67, 83] - 15).midicps * tape, mul: [1, 0.9, 0.7, 0.25]);
	c = Splay.ar(inArray: c, spread: 0.7, center: 0.0);
	c = (c * SinOsc.ar(freq: 0.1, phase: 1.5pi, mul: 2, add: 3)).tanh; // Oscillating Distortion

	// d - Treble Harmony, f - Demand FM Operator
	f = SinOsc.ar(freq: Demand.ar(trig: Impulse.ar(4),reset: 0, demandUGens: Dseq(list: (Array.series(20, 0.1, 0.1) * 48.midicps), repeats: inf)), mul: 0.04, add: 1);

	d = SinOsc.ar(freq: ([59, 60, 64] + 21).midicps * f * tape) *
	        Lag.ar(Pulse.ar(freq: [4, 4.01, 4.02], // Pulse the volume with phasing
		       width: SinOsc.ar(freq: 0.08, mul: 0.4, add: 0.2)), // Oscillate the width of the pulse
	        lagTime: 0.02 // Soften the pulse transients
	        );
	d = Splay.ar(inArray: d, spread: 0.5, center: SinOsc.ar(freq: 0.03, mul: 0.15));

	// e = Occasional Treble Harmony 2
	e = SinOsc.ar(freq: ([67,69] + 23).midicps * f * tape) *
	        Lag.ar(Pulse.ar(freq: [0.04,0.045], // Pulse the volume with phasing
		       width: 0.01), // Oscillate the width of the pulse
	        lagTime: 0.1 // Soften the pulse transients
	        );
	e = Splay.ar(inArray: e, spread: 0.4, center: SinOsc.ar(freq: 0.03, mul: 0.15));

	// z - Output
	z = Pan2.ar(in: c, pos: 0.0, level: 0.025 * ( SinOsc.ar(0.02, mul: 0.5, add: 0.5))) + // Bass Harmony
	        Pan2.ar(in: d, pos: 0.0, level: 0.06 * ( SinOsc.ar(0.03, mul: 0.4, add: 0.6))) + // Treble Harmony
	        Pan2.ar(in: e, pos: 0.0, level: 0.00004); // Treble Harmony 2

	// v - Volume Envelope
	v = EnvGen.ar(Env.circle(levels: [0, 1, 1, 0, 0], times: [20, 60, 20, 10], curve: \lin));

	z = z * v;

	z = FreeVerb.ar(in: z, mix: 0.36 * tape, room: 0.7, damp: 0.4, mul: 1.0);

}.play;

)
